==> react-app-logic-11.1.0.tgz: package/src/exchange/forms/useExchangePairs.ts <==
import { useMemo } from 'react';
import { useAsyncStatuses } from '@onomy/react-utils';
import { DetailedFungibleAssetOnChain } from '@onomy/hub';
import { useSupportedAssetList } from '@onomy/react-hub';
import { useOnexClient } from '../hooks';

type ExchangePairMap = Record<
  string,
  | {
      quoteAsset: DetailedFungibleAssetOnChain;
      pairs: Array<{
        quoteAsset: DetailedFungibleAssetOnChain;
        baseAsset: DetailedFungibleAssetOnChain;
        pair: string;
      }>;
    }
  | undefined
>;

export function useExchangePairs() {
  const onex = useOnexClient();
  const [allAssets, assetsStatus] = useSupportedAssetList();

  const onexAssets = useMemo(() => {
    const chainId = onex.getBlockchain().name;
    const res = allAssets.filter(asset => {
      return asset.chain.name === chainId && asset.id !== 'anom' && asset.id !== 'onex';
    });
    const anom = allAssets.find(asset => {
      return asset.chain.name === chainId && asset.id === 'anom';
    });
    return anom ? [anom, ...res] : res;
  }, [allAssets, onex]);

  const quoteAssets = onexAssets; // TODO: manual filter/sort?

  const pairsByQuote = useMemo(() => {
    return onexAssets.reduce((res, quoteAsset) => {
      return {
        ...res,
        [quoteAsset.id]: {
          quoteAsset,
          pairs: onexAssets
            .filter(asset => asset.id !== quoteAsset.id)
            .map(baseAsset => {
              return {
                quoteAsset,
                baseAsset,
                pair: [quoteAsset.id, baseAsset.id].sort().join(','),
              };
            }),
        },
      };
    }, {} as ExchangePairMap);
  }, [onexAssets]);

  const loadingStatus = useAsyncStatuses([assetsStatus]);

  return {
    loadingStatus,
    assetsStatus,

    onexAssets,
    quoteAssets,
    pairsByQuote,
  };
}

==> react-app-logic-17.1.0.tgz: package/src/exchange/forms/useExchangePairs.ts <==
import { useMemo } from 'react';
import { useAsyncStatuses } from '@onomy/react-utils';
import { DetailedFungibleAssetOnChain } from '@onomy/hub';
import { useSupportedAssetList } from '@onomy/react-hub';
import { useOnexClient } from '../hooks';

type ExchangePairMap = Record<
  string,
  | {
      quoteAsset: DetailedFungibleAssetOnChain;
      pairs: Array<{
        quoteAsset: DetailedFungibleAssetOnChain;
        baseAsset: DetailedFungibleAssetOnChain;
        pair: string;
      }>;
    }
  | undefined
>;

export function useExchangePairs() {
  const onex = useOnexClient();
  const [allAssets, assetsStatus] = useSupportedAssetList();

  const onexAssets = useMemo(() => {
    const chainId = onex?.getBlockchain().name ?? '';
    const res = allAssets.filter(asset => {
      return asset.chain.name === chainId && asset.id !== 'anom' && asset.id !== 'onex';
    });
    const anom = allAssets.find(asset => {
      return asset.chain.name === chainId && asset.id === 'anom';
    });
    return anom ? [anom, ...res] : res;
  }, [allAssets, onex]);

  const quoteAssets = onexAssets; // TODO: manual filter/sort?

  const pairsByQuote = useMemo(() => {
    return onexAssets.reduce((res, quoteAsset) => {
      return {
        ...res,
        [quoteAsset.id]: {
          quoteAsset,
          pairs: onexAssets
            .filter(asset => asset.id !== quoteAsset.id)
            .map(baseAsset => {
              return {
                quoteAsset,
                baseAsset,
                pair: [quoteAsset.id, baseAsset.id].sort().join(','),
              };
            }),
        },
      };
    }, {} as ExchangePairMap);
  }, [onexAssets]);

  const loadingStatus = useAsyncStatuses([assetsStatus]);

  return {
    loadingStatus,
    assetsStatus,

    onexAssets,
    quoteAssets,
    pairsByQuote,
  };
}
